@@ -324,16 +324,21 @@ void qjackctlClientItem::markClientPorts ( int iMark )
 		(iter.next())->markPort(iMark);
 }
 
-void qjackctlClientItem::cleanClientPorts ( int iMark )
+int qjackctlClientItem::cleanClientPorts ( int iMark )
 {
+	int iDirtyCount = 0;
+
 	QMutableListIterator<qjackctlPortItem *> iter(m_ports);
 	while (iter.hasNext()) {
 		qjackctlPortItem *pPort = iter.next();
 		if (pPort->portMark() == iMark) {
 			iter.remove();
 			delete pPort;
+			iDirtyCount++;
 		}
 	}
+	
+	return iDirtyCount;
 }
 
 int qjackctlClientItem::clientMark (void) const
@@ -475,18 +480,23 @@ void qjackctlClientList::markClientPorts ( int iMark )
 		(iter.next())->markClientPorts(iMark);
 }
 
-void qjackctlClientList::cleanClientPorts ( int iMark )
+int qjackctlClientList::cleanClientPorts ( int iMark )
 {
+	int iDirtyCount = 0;
+	
 	QMutableListIterator<qjackctlClientItem *> iter(m_clients);
 	while (iter.hasNext()) {
 		qjackctlClientItem *pClient = iter.next();
 		if (pClient->clientMark() == iMark) {
 			iter.remove();
 			delete pClient;
+			iDirtyCount++;
 		} else {
-			pClient->cleanClientPorts(iMark);
+			iDirtyCount += pClient->cleanClientPorts(iMark);
 		}
 	}
+
+	return iDirtyCount;
 }
 
 // Client:port hilite update stabilization.
@@ -595,6 +605,16 @@ bool qjackctlClientList::lessThan (
 }
 
 
+// Do proper contents refresh/update.
+void qjackctlClientList::refresh (void)
+{
+	QHeaderView *pHeader = m_pListView->header();
+	m_pListView->sortItems(
+		pHeader->sortIndicatorSection(),
+		pHeader->sortIndicatorOrder());
+}
+
+
 //----------------------------------------------------------------------------
 // qjackctlClientListView -- Client list view, supporting drag-n-drop.
 
@@ -988,6 +1008,7 @@ void qjackctlClientListView::contextMenuEvent ( QContextMenuEvent *pContextMenuE
 }
 
 
+
 //----------------------------------------------------------------------
 // qjackctlConnectorView -- Jack port connector widget.
 //
@@ -1347,25 +1368,37 @@ void qjackctlConnect::setIClientList ( qjackctlClientList *pIClientList )
 
 
 // Connection primitive.
-void qjackctlConnect::connectPortsEx (
+bool qjackctlConnect::connectPortsEx (
 	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
 {
-	if (pOPort->findConnectPtr(pIPort) == NULL) {
-		connectPorts(pOPort, pIPort);
-		pOPort->addConnect(pIPort);
-		pIPort->addConnect(pOPort);
-	}
+	if (pOPort->findConnectPtr(pIPort) != NULL)
+		return false;
+	
+	emit connecting(pOPort, pIPort);
+
+	if (!connectPorts(pOPort, pIPort))
+		return false;
+
+	pOPort->addConnect(pIPort);
+	pIPort->addConnect(pOPort);
+	return true;
 }
 
 // Disconnection primitive.
-void qjackctlConnect::disconnectPortsEx (
+bool qjackctlConnect::disconnectPortsEx (
 	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
 {
-	if (pOPort->findConnectPtr(pIPort) != 0) {
-		disconnectPorts(pOPort, pIPort);
-		pOPort->removeConnect(pIPort);
-		pIPort->removeConnect(pOPort);
-	}
+	if (pOPort->findConnectPtr(pIPort) == NULL)
+		return false;
+
+	emit disconnecting(pOPort, pIPort);
+
+	if (!disconnectPorts(pOPort, pIPort))
+		return false;
+
+	pOPort->removeConnect(pIPort);
+	pIPort->removeConnect(pOPort);
+	return true;
 }
 
 
@@ -1761,8 +1794,14 @@ void qjackctlConnect::updateContents ( bool bClear )
 			updateIconPixmaps();
 		}
 		// Add (newer) client:ports and respective connections...
-		iDirtyCount += m_pOClientList->updateClientPorts();
-		iDirtyCount += m_pIClientList->updateClientPorts();
+		if (m_pOClientList->updateClientPorts() > 0) {
+			m_pOClientList->refresh();
+			iDirtyCount++;
+		}
+		if (m_pIClientList->updateClientPorts() > 0) {
+			m_pIClientList->refresh();
+			iDirtyCount++;
+		}			
 		updateConnections();
 		endMutex();
 	}
