@@ -137,8 +137,7 @@ public:
 	// Client port cleanup marker.
 	void markClient(int iMark);
 	void markClientPorts(int iMark);
-	void cleanClientPorts(int iMark);
-
+	int cleanClientPorts(int iMark);
 	int clientMark() const;
 
 	// Connectiopn highlight methods.
@@ -198,7 +197,7 @@ public:
 
 	// Client ports cleanup marker.
 	void markClientPorts(int iMark);
-	void cleanClientPorts(int iMark);
+	int cleanClientPorts(int iMark);
 
 	// Client:port refreshner (return newest item count).
 	virtual int updateClientPorts() = 0;
@@ -206,6 +205,9 @@ public:
 	// Client:port hilite update stabilization.
 	void hiliteClientPorts (void);
 
+	// Do proper contents refresh/update.
+	void refresh();
+
 	// Natural decimal sorting comparator.
 	static bool lessThan(const QTreeWidgetItem& i1, const QTreeWidgetItem& i2);
 
@@ -448,12 +450,16 @@ signals:
 	// Connection change signal.
 	void connectChanged();
 
+	// Pre-notification of (dis)connection.
+	void connecting(qjackctlPortItem *, qjackctlPortItem *);
+	void disconnecting(qjackctlPortItem *, qjackctlPortItem *);
+
 protected:
 
 	// Connect/Disconnection primitives.
-	virtual void connectPorts(
+	virtual bool connectPorts(
 		qjackctlPortItem *pOPort, qjackctlPortItem *pIPort) = 0;
-	virtual void disconnectPorts(
+	virtual bool disconnectPorts(
 		qjackctlPortItem *pOPort, qjackctlPortItem *pIPort) = 0;
 
 	// Update port connection references.
@@ -485,8 +491,8 @@ private:
 	bool disconnectAllEx();
 
 	// Connect/Disconnection local primitives.
-	void connectPortsEx(qjackctlPortItem *pOPort, qjackctlPortItem *pIPort);
-	void disconnectPortsEx(qjackctlPortItem *pOPort, qjackctlPortItem *pIPort);
+	bool connectPortsEx(qjackctlPortItem *pOPort, qjackctlPortItem *pIPort);
+	bool disconnectPortsEx(qjackctlPortItem *pOPort, qjackctlPortItem *pIPort);
 
 	// Instance variables.
 	qjackctlConnectView *m_pConnectView;
