@@ -25,6 +25,7 @@
 #include "qjackctlSetup.h"
 
 #include "qjackctlMainForm.h"
+#include "qjackctlPatchbay.h"
 
 #include <QMessageBox>
 
@@ -168,6 +169,16 @@ void qjackctlConnectionsForm::hideEvent ( QHideEvent *pHideEvent )
 		pMainForm->stabilizeForm();
 }
 
+// Just about to notify main-window that we're closing.
+void qjackctlConnectionsForm::closeEvent ( QCloseEvent * /*pCloseEvent*/ )
+{
+	QWidget::hide();
+
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm)
+		pMainForm->stabilizeForm();
+}
+
 
 // Set reference to global options, mostly needed for the
 // initial sizes of the main splitter views and those
@@ -185,6 +196,12 @@ void qjackctlConnectionsForm::setup ( qjackctlSetup *pSetup )
 		m_pSetup->loadSplitterSizes(m_ui.AudioConnectView, sizes);
 		m_pSetup->loadSplitterSizes(m_ui.MidiConnectView, sizes);
 		m_pSetup->loadSplitterSizes(m_ui.AlsaConnectView, sizes);
+#ifdef CONFIG_ALSA_SEQ
+		if (!m_pSetup->bAlsaSeqEnabled) {
+		//	m_ui.ConnectionsTabWidget->setTabEnabled(2, false);
+			m_ui.ConnectionsTabWidget->removeTab(2);
+		}
+#endif
 	}
 
 	// Update initial client/port aliases...
@@ -334,12 +351,18 @@ void qjackctlConnectionsForm::setJackClient ( jack_client_t *pJackClient )
 				m_ui.AudioConnectView, pJackClient, QJACKCTL_JACK_AUDIO);
 			QObject::connect(m_pAudioConnect, SIGNAL(connectChanged()),
 				pMainForm, SLOT(jackConnectChanged()));
+			QObject::connect(m_pAudioConnect,
+				SIGNAL(disconnecting(qjackctlPortItem *, qjackctlPortItem *)),
+				SLOT(audioDisconnecting(qjackctlPortItem *, qjackctlPortItem *)));
 		}
 		if (m_pMidiConnect == NULL && pMainForm) {
 			m_pMidiConnect = new qjackctlJackConnect(
 				m_ui.MidiConnectView, pJackClient, QJACKCTL_JACK_MIDI);
 			QObject::connect(m_pMidiConnect, SIGNAL(connectChanged()),
 				pMainForm, SLOT(jackConnectChanged()));
+			QObject::connect(m_pMidiConnect,
+				SIGNAL(disconnecting(qjackctlPortItem *, qjackctlPortItem *)),
+				SLOT(midiDisconnecting(qjackctlPortItem *, qjackctlPortItem *)));
 		}
 	}
 
@@ -359,11 +382,14 @@ void qjackctlConnectionsForm::setAlsaSeq ( snd_seq_t *pAlsaSeq )
 	}
 
 	if (pAlsaSeq && m_pAlsaConnect == NULL) {
+		qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
 		m_pAlsaConnect = new qjackctlAlsaConnect(m_ui.AlsaConnectView, pAlsaSeq);
-		if (m_pAlsaConnect) {
-			qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-			if (pMainForm)
-				QObject::connect(m_pAlsaConnect, SIGNAL(connectChanged()), pMainForm, SLOT(alsaConnectChanged()));
+		if (pMainForm) {
+			QObject::connect(m_pAlsaConnect, SIGNAL(connectChanged()),
+				pMainForm, SLOT(alsaConnectChanged()));
+			QObject::connect(m_pAlsaConnect,
+				SIGNAL(disconnecting(qjackctlPortItem *, qjackctlPortItem *)),
+				SLOT(alsaDisconnecting(qjackctlPortItem *, qjackctlPortItem *)));
 		}
 	}
 
@@ -413,6 +439,16 @@ void qjackctlConnectionsForm::audioDisconnectAll (void)
 }
 
 
+// JACK audio ports disconnecting.
+void qjackctlConnectionsForm::audioDisconnecting (
+	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
+{
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm)
+		pMainForm->queryDisconnect(pOPort, pIPort, QJACKCTL_SOCKETTYPE_AUDIO);
+}
+
+
 // Refresh JACK audio form by notifying the parent form.
 void qjackctlConnectionsForm::audioRefresh (void)
 {
@@ -469,6 +505,18 @@ void qjackctlConnectionsForm::midiDisconnectAll (void)
 }
 
 
+// JACK MIDI ports disconnecting.
+void qjackctlConnectionsForm::midiDisconnecting (
+	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
+{
+	// FIXME: Patchbay may not support JACK MIDI yet!
+	// take it as stub and make it like audio type...
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm)
+		pMainForm->queryDisconnect(pOPort, pIPort, QJACKCTL_SOCKETTYPE_AUDIO);
+}
+
+
 // Refresh JACK MIDI form by notifying the parent form.
 void qjackctlConnectionsForm::midiRefresh (void)
 {
@@ -495,7 +543,7 @@ bool qjackctlConnectionsForm::isAlsaConnected (void) const
 }
 
 
-// Connect current selected ports.
+// Connect current selected ALSA MIDI ports.
 void qjackctlConnectionsForm::alsaConnectSelected (void)
 {
 	if (m_pAlsaConnect) {
@@ -505,7 +553,7 @@ void qjackctlConnectionsForm::alsaConnectSelected (void)
 }
 
 
-// Disconnect current selected ports.
+// Disconnect current selected ALSA MIDI ports.
 void qjackctlConnectionsForm::alsaDisconnectSelected (void)
 {
 	if (m_pAlsaConnect) {
@@ -515,7 +563,7 @@ void qjackctlConnectionsForm::alsaDisconnectSelected (void)
 }
 
 
-// Disconnect all connected ports.
+// Disconnect all connected ALSA MIDI ports.
 void qjackctlConnectionsForm::alsaDisconnectAll (void)
 {
 	if (m_pAlsaConnect) {
@@ -525,6 +573,16 @@ void qjackctlConnectionsForm::alsaDisconnectAll (void)
 }
 
 
+// ALSA MIDI ports disconnecting.
+void qjackctlConnectionsForm::alsaDisconnecting (
+	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
+{
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm)
+		pMainForm->queryDisconnect(pOPort, pIPort, QJACKCTL_SOCKETTYPE_MIDI);
+}
+
+
 // Refresh complete form by notifying the parent form.
 void qjackctlConnectionsForm::alsaRefresh (void)
 {
