@@ -23,6 +23,8 @@
 #include "qjackctlMainForm.h"
 
 #include "qjackctlStatus.h"
+
+#include "qjackctlPatchbay.h"
 #include "qjackctlPatchbayFile.h"
 
 #include "qjackctlMessagesForm.h"
@@ -225,6 +227,9 @@ qjackctlMainForm::qjackctlMainForm (
 	m_pConnectionsForm = NULL;
 	m_pPatchbayForm    = NULL;
 
+	// Patchbay rack can be readily created.
+	m_pPatchbayRack = new qjackctlPatchbayRack();
+
 	// The eventual system tray widget.
 	m_pSystemTray  = NULL;
 
@@ -331,6 +336,10 @@ qjackctlMainForm::~qjackctlMainForm (void)
 	if (m_pSystemTray)
 		delete m_pSystemTray;
 
+	// Patchbay rack is also dead.
+	if (m_pPatchbayRack)
+		delete m_pPatchbayRack;
+
 	// Pseudo-singleton reference shut-down.
 	g_pMainForm = NULL;
 }
@@ -357,28 +366,33 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
 	updateButtons();
 
 	// What style do we create these forms?
+	QWidget *pParent = NULL;
 	Qt::WindowFlags wflags = Qt::Window
+#if QT_VERSION >= 0x040200
 		| Qt::CustomizeWindowHint
+#endif
 		| Qt::WindowTitleHint
 		| Qt::WindowSystemMenuHint
 		| Qt::WindowMinMaxButtonsHint;
-	if (m_pSetup->bKeepOnTop)
+	if (m_pSetup->bKeepOnTop) {
+		pParent = this;
 		wflags |= Qt::Tool;
+	}
 	// All forms are to be created right now.
-	m_pMessagesForm    = new qjackctlMessagesForm    (this, wflags);
-	m_pStatusForm      = new qjackctlStatusForm      (this, wflags);
-	m_pConnectionsForm = new qjackctlConnectionsForm (this, wflags);
-	m_pPatchbayForm    = new qjackctlPatchbayForm    (this, wflags);
+	m_pMessagesForm    = new qjackctlMessagesForm    (pParent, wflags);
+	m_pStatusForm      = new qjackctlStatusForm      (pParent, wflags);
+	m_pConnectionsForm = new qjackctlConnectionsForm (pParent, wflags);
+	m_pPatchbayForm    = new qjackctlPatchbayForm    (pParent, wflags);
 	// Setup appropriately...
 	m_pConnectionsForm->setup(m_pSetup);
 	m_pPatchbayForm->setup(m_pSetup);
 
 	// Set the patchbay cable connection notification signal/slot.
-	QObject::connect(&m_patchbayRack, SIGNAL(cableConnected(const QString&, const QString&, unsigned int)),
+	QObject::connect(m_pPatchbayRack, SIGNAL(cableConnected(const QString&, const QString&, unsigned int)),
 		this, SLOT(cableConnectSlot(const QString&, const QString&, unsigned int)));
 
 	// Try to restore old window positioning and appearence.
-	m_pSetup->loadWidgetGeometry(this);
+	m_pSetup->loadWidgetGeometry(this, m_pSetup->bStartMinimized);
 
 	// Make it final show...
 	m_ui.StatusDisplayFrame->show();
@@ -415,43 +429,50 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
 	}
 #endif
 #ifdef CONFIG_ALSA_SEQ
-	// Start our ALSA sequencer interface.
-	if (snd_seq_open(&m_pAlsaSeq, "hw", SND_SEQ_OPEN_DUPLEX, 0) < 0)
-		m_pAlsaSeq = NULL;
-	if (m_pAlsaSeq) {
-		snd_seq_port_subscribe_t *pAlsaSubs;
-		snd_seq_addr_t seq_addr;
-		int iPort;
-		struct pollfd pfd[1];
-		iPort = snd_seq_create_simple_port(
-			m_pAlsaSeq,
-			"qjackctl",
-			SND_SEQ_PORT_CAP_WRITE|SND_SEQ_PORT_CAP_SUBS_WRITE|SND_SEQ_PORT_CAP_NO_EXPORT,
-			SND_SEQ_PORT_TYPE_APPLICATION
-		);
-		if (iPort >= 0) {
-			snd_seq_port_subscribe_alloca(&pAlsaSubs);
-			seq_addr.client = SND_SEQ_CLIENT_SYSTEM;
-			seq_addr.port   = SND_SEQ_PORT_SYSTEM_ANNOUNCE;
-			snd_seq_port_subscribe_set_sender(pAlsaSubs, &seq_addr);
-			seq_addr.client = snd_seq_client_id(m_pAlsaSeq);
-			seq_addr.port   = iPort;
-			snd_seq_port_subscribe_set_dest(pAlsaSubs, &seq_addr);
-			snd_seq_subscribe_port(m_pAlsaSeq, pAlsaSubs);
-			snd_seq_poll_descriptors(m_pAlsaSeq, pfd, 1, POLLIN);
-			m_pAlsaNotifier = new QSocketNotifier(pfd[0].fd, QSocketNotifier::Read);
-			QObject::connect(m_pAlsaNotifier, SIGNAL(activated(int)), this, SLOT(alsaNotifySlot(int)));
+	if (m_pSetup->bAlsaSeqEnabled) {
+		// Start our ALSA sequencer interface.
+		if (snd_seq_open(&m_pAlsaSeq, "hw", SND_SEQ_OPEN_DUPLEX, 0) < 0)
+			m_pAlsaSeq = NULL;
+		if (m_pAlsaSeq) {
+			snd_seq_port_subscribe_t *pAlsaSubs;
+			snd_seq_addr_t seq_addr;
+			struct pollfd pfd[1];
+			int iPort = snd_seq_create_simple_port(
+				m_pAlsaSeq,	"qjackctl",
+				SND_SEQ_PORT_CAP_WRITE
+				| SND_SEQ_PORT_CAP_SUBS_WRITE
+				| SND_SEQ_PORT_CAP_NO_EXPORT,
+				SND_SEQ_PORT_TYPE_APPLICATION
+			);
+			if (iPort >= 0) {
+				snd_seq_port_subscribe_alloca(&pAlsaSubs);
+				seq_addr.client = SND_SEQ_CLIENT_SYSTEM;
+				seq_addr.port   = SND_SEQ_PORT_SYSTEM_ANNOUNCE;
+				snd_seq_port_subscribe_set_sender(pAlsaSubs, &seq_addr);
+				seq_addr.client = snd_seq_client_id(m_pAlsaSeq);
+				seq_addr.port   = iPort;
+				snd_seq_port_subscribe_set_dest(pAlsaSubs, &seq_addr);
+				snd_seq_subscribe_port(m_pAlsaSeq, pAlsaSubs);
+				snd_seq_poll_descriptors(m_pAlsaSeq, pfd, 1, POLLIN);
+				m_pAlsaNotifier
+					= new QSocketNotifier(pfd[0].fd, QSocketNotifier::Read);
+				QObject::connect(m_pAlsaNotifier,
+					SIGNAL(activated(int)),
+					SLOT(alsaNotifySlot(int)));
+			}
+		}
+		// Could we start without it?
+		if (m_pAlsaSeq) {
+			// Rather obvious setup.
+			if (m_pConnectionsForm)
+				m_pConnectionsForm->setAlsaSeq(m_pAlsaSeq);
+			if (m_pPatchbayForm)
+				m_pPatchbayForm->setAlsaSeq(m_pAlsaSeq);
+		} else {
+			appendMessagesError(
+				tr("Could not open ALSA sequencer as a client.\n\n"
+				"ALSA MIDI patchbay will be not available."));
 		}
-	}
-	// Could we start without it?
-	if (m_pAlsaSeq == NULL) {
-		appendMessagesError(tr("Could not open ALSA sequencer as a client.\n\nMIDI patchbay will be not available."));
-	} else {
-		// Rather obvious setup.
-		if (m_pConnectionsForm)
-			m_pConnectionsForm->setAlsaSeq(m_pAlsaSeq);
-		if (m_pPatchbayForm)
-			m_pPatchbayForm->setAlsaSeq(m_pAlsaSeq);
 	}
 #endif
 
@@ -492,8 +513,13 @@ bool qjackctlMainForm::queryClose (void)
 	// If we're not quitting explicitly and there's an
 	// active system tray icon, then just hide ourselves.
 	if (!m_bQuitForce && isVisible()
-		&& m_pSetup->bSystemTray && m_pSystemTray && m_pJackClient) {
+		&& m_pSetup->bSystemTray && m_pSystemTray) {
 		m_pSetup->saveWidgetGeometry(this);
+        QMessageBox::information(this,
+			tr("Information") + " - " QJACKCTL_SUBTITLE1,
+			tr("The program will keep running in the system tray.\n\n"
+			"To terminate the program, please choose \"Quit\" "
+			"in the context menu of the system tray entry."));
 		hide();
 		bQueryClose = false;
 	}
@@ -543,6 +569,8 @@ bool qjackctlMainForm::queryClose (void)
 		// And the system tray icon too.
 		if (m_pSystemTray)
 			m_pSystemTray->close();
+		// Stop any service out there...
+		stopJackServer();
 	}
 
 #ifdef CONFIG_SYSTEM_TRAY
@@ -851,7 +879,7 @@ void qjackctlMainForm::startJack (void)
 		else if (m_preset.iOutChannels > 0)
 			args.append("-o" + QString::number(m_preset.iOutChannels));
 	}
-	else if (bCoreaudio || bFirewire) {
+	else if (bCoreaudio || bPortaudio || bFirewire) {
 		if (m_preset.iInChannels > 0  && m_preset.iAudio != QJACKCTL_PLAYBACK)
 			args.append("-i" + QString::number(m_preset.iInChannels));
 		if (m_preset.iOutChannels > 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
@@ -896,7 +924,7 @@ void qjackctlMainForm::startJack (void)
 		if (m_preset.bHWMeter)
 			args.append("-M");
 	}
-	if (bAlsa || bOss || bCoreaudio || bFreebob) {
+	if (bAlsa || bOss || bCoreaudio || bPortaudio || bFreebob) {
 		if (m_preset.iInLatency > 0)
 			args.append("-I" + QString::number(m_preset.iInLatency));
 		if (m_preset.iOutLatency > 0)
@@ -1456,7 +1484,7 @@ void qjackctlMainForm::updateActivePatchbay (void)
 
 	// Time to load the active patchbay rack profiler?
 	if (m_pSetup->bActivePatchbay && !m_pSetup->sActivePatchbayPath.isEmpty()) {
-		if (!qjackctlPatchbayFile::load(&m_patchbayRack, m_pSetup->sActivePatchbayPath)) {
+		if (!qjackctlPatchbayFile::load(m_pPatchbayRack, m_pSetup->sActivePatchbayPath)) {
 			appendMessagesError(tr("Could not load active patchbay definition.\n\nDisabled."));
 			m_pSetup->bActivePatchbay = false;
 		} else {
@@ -1839,7 +1867,7 @@ void qjackctlMainForm::timerSlot (void)
 			if (m_pSetup->bActivePatchbay) {
 				appendMessagesColor(
 					tr("Audio active patchbay scan") + sEllipsis, "#6699cc");
-				m_patchbayRack.connectAudioScan(m_pJackClient);
+				m_pPatchbayRack->connectAudioScan(m_pJackClient);
 			}
 			refreshJackConnections();
 		}
@@ -1849,10 +1877,11 @@ void qjackctlMainForm::timerSlot (void)
 			if (m_pSetup->bActivePatchbay) {
 				appendMessagesColor(
 					tr("MIDI active patchbay scan") + sEllipsis, "#99cc66");
-				m_patchbayRack.connectMidiScan(m_pAlsaSeq);
+				m_pPatchbayRack->connectMidiScan(m_pAlsaSeq);
 			}
 			refreshAlsaConnections();
 		}
+#ifdef CONFIG_AUTO_REFRESH
 		// Shall we refresh connections now and then?
 		if (m_pSetup->bAutoRefresh) {
 			m_iTimerRefresh += QJACKCTL_TIMER_MSECS;
@@ -1861,6 +1890,7 @@ void qjackctlMainForm::timerSlot (void)
 				refreshConnections();
 			}
 		}
+#endif
 		// Are we about to refresh it, really?
 		if (m_iJackRefresh > 0) {
 			m_iJackRefresh = 0;
@@ -1942,6 +1972,32 @@ void qjackctlMainForm::cableConnectSlot (
 }
 
 
+// Patchbay (dis)connection slot.
+void qjackctlMainForm::queryDisconnect (
+	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort, int iSocketType )
+{
+	if (m_pSetup->bActivePatchbay) {
+		qjackctlPatchbayCable *pCable = m_pPatchbayRack->findCable(
+			pOPort->clientName(), pOPort->portName(),
+			pIPort->clientName(), pIPort->portName(), iSocketType); 
+		if (pCable && QMessageBox::warning(this,
+			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
+			tr("A patchbay definition is currently active,\n"
+			"which is probable to redo this connection:\n\n"
+			"%1 -> %2\n\n"
+			"Do you want to remove the patchbay connection?")
+			.arg(pCable->outputSocket()->name())
+			.arg(pCable->inputSocket()->name()),
+			tr("Remove"), tr("Ignore")) == 0) {
+			m_pPatchbayRack->removeCable(pCable);
+			if (m_pPatchbayForm
+				&& isActivePatchbay(m_pPatchbayForm->patchbayPath()))
+				m_pPatchbayForm->loadPatchbayRack(m_pPatchbayRack);
+		}
+	}
+}
+
+
 // Start our jack audio control client...
 bool qjackctlMainForm::startJackClient ( bool bDetach )
 {
@@ -2063,8 +2119,8 @@ bool qjackctlMainForm::startJackClient ( bool bDetach )
 	pal.setColor(QPalette::Foreground, Qt::yellow);
 	m_ui.ServerStateTextLabel->setPalette(pal);
 	m_ui.DspLoadTextLabel->setPalette(pal);
-	pal.setColor(QPalette::Foreground, Qt::darkYellow);
 	m_ui.ServerModeTextLabel->setPalette(pal);
+	pal.setColor(QPalette::Foreground, Qt::darkYellow);
 	m_ui.SampleRateTextLabel->setPalette(pal);
 	pal.setColor(QPalette::Foreground, Qt::green);
 	m_ui.TimeDisplayTextLabel->setPalette(pal);
@@ -2303,6 +2359,7 @@ void qjackctlMainForm::showSetupForm (void)
 		int     bOldMessagesLimit       = m_pSetup->bMessagesLimit;
 		int     iOldMessagesLimitLines  = m_pSetup->iMessagesLimitLines;
 		bool    bOldBezierLines         = m_pSetup->bBezierLines;
+		bool    bOldAlsaSeqEnabled      = m_pSetup->bAlsaSeqEnabled;
 		bool    bOldAliasesEnabled      = m_pSetup->bAliasesEnabled;
 		bool    bOldAliasesEditing      = m_pSetup->bAliasesEditing;
 		bool    bOldLeftButtons         = m_pSetup->bLeftButtons;
@@ -2358,12 +2415,14 @@ void qjackctlMainForm::showSetupForm (void)
 				(!bOldTextLabels &&  m_pSetup->bTextLabels))
 				updateButtons();
 			// Warn if something will be only effective on next run.
-			if (( bOldStdoutCapture && !m_pSetup->bStdoutCapture) ||
-				(!bOldStdoutCapture &&  m_pSetup->bStdoutCapture) ||
-				( bOldKeepOnTop     && !m_pSetup->bKeepOnTop)     ||
-				(!bOldKeepOnTop     &&  m_pSetup->bKeepOnTop)     ||
-				( bOldDelayedSetup  && !m_pSetup->bDelayedSetup)  ||
-				(!bOldDelayedSetup  &&  m_pSetup->bDelayedSetup))
+			if (( bOldStdoutCapture  && !m_pSetup->bStdoutCapture)  ||
+				(!bOldStdoutCapture  &&  m_pSetup->bStdoutCapture)  ||
+				( bOldKeepOnTop      && !m_pSetup->bKeepOnTop)      ||
+				(!bOldKeepOnTop      &&  m_pSetup->bKeepOnTop)      ||
+				( bOldDelayedSetup   && !m_pSetup->bDelayedSetup)   ||
+				(!bOldDelayedSetup   &&  m_pSetup->bDelayedSetup)   ||
+				( bOldAlsaSeqEnabled && !m_pSetup->bAlsaSeqEnabled) ||
+				(!bOldAlsaSeqEnabled &&  m_pSetup->bAlsaSeqEnabled))
 				showDirtySetupWarning();
 			// If server is currently running, warn user...
 			showDirtySettingsWarning();
@@ -2526,11 +2585,13 @@ void qjackctlMainForm::refreshStatus (void)
 				tr("%1 Hz").arg(jack_get_sample_rate(m_pJackClient)));
 			updateStatusItem(STATUS_BUFFER_SIZE,
 				tr("%1 frames").arg(g_nframes));
-			// Blink server mode indicator...
-			QPalette pal;
-			pal.setColor(QPalette::Foreground,
-				(++m_iStatusBlink % 2) ? Qt::darkYellow: Qt::yellow);
-			m_ui.ServerModeTextLabel->setPalette(pal);
+			// Blink server mode indicator?...
+			if (m_pSetup && m_pSetup->bDisplayBlink) {
+				QPalette pal;
+				pal.setColor(QPalette::Foreground,
+					(++m_iStatusBlink % 2) ? Qt::darkYellow: Qt::yellow);
+				m_ui.ServerModeTextLabel->setPalette(pal);
+			}
 #ifdef CONFIG_JACK_REALTIME
 			bool bRealtime = jack_is_realtime(m_pJackClient);
 			updateStatusItem(STATUS_REALTIME,
@@ -2769,6 +2830,9 @@ void qjackctlMainForm::updateSystemTray (void)
 		QObject::connect(m_pSystemTray,
 			SIGNAL(clicked()),
 			SLOT(toggleMainForm()));
+		QObject::connect(m_pSystemTray,
+			SIGNAL(middleClicked()),
+			SLOT(resetXrunStats()));
 		QObject::connect(m_pSystemTray,
 			SIGNAL(contextMenuRequested(const QPoint &)),
 			SLOT(systemTrayContextMenu(const QPoint &)));
@@ -2942,11 +3006,20 @@ void qjackctlMainForm::quitMainForm (void)
 
 
 // Context menu event handler.
-void qjackctlMainForm::contextMenuEvent( QContextMenuEvent *pEvent )
+void qjackctlMainForm::contextMenuEvent ( QContextMenuEvent *pEvent )
 {
 	// We'll just show up the usual system tray menu.
 	systemTrayContextMenu(pEvent->globalPos());
 }
 
 
+void qjackctlMainForm::mousePressEvent(QMouseEvent *pMouseEvent)
+{
+	if (pMouseEvent->button() == Qt::MidButton &&
+		m_ui.StatusDisplayFrame->geometry().contains(pMouseEvent->pos())) {
+		resetXrunStats();
+	}
+}
+
+
 // end of qjackctlMainForm.cpp
