@@ -25,18 +25,28 @@
 #include "ui_qjackctlMainForm.h"
 
 #include "qjackctlSetup.h"
-#include "qjackctlPatchbay.h"
 
 #include <QProcess>
 #include <QDateTime>
 
+#include <jack/jack.h>
+
+#ifdef CONFIG_ALSA_SEQ
+#include <alsa/asoundlib.h>
+#else
+typedef void snd_seq_t;
+#endif
+
+
 // Forward declarations.
 class qjackctlSetup;
 class qjackctlMessagesForm;
 class qjackctlStatusForm;
 class qjackctlConnectionsForm;
 class qjackctlPatchbayForm;
+class qjackctlPatchbayRack;
 class qjackctlSystemTray;
+class qjackctlPortItem;
 
 class QSocketNotifier;
 
@@ -68,7 +78,6 @@ public:
 
 	void stabilize(int msecs);
 
-	void resetXrunStats();
 	void refreshXrunStats();
 
 	void refreshJackConnections();
@@ -76,6 +85,9 @@ public:
 
 	void refreshPatchbay();
 
+	void queryDisconnect(
+		qjackctlPortItem *pOPort, qjackctlPortItem *pIPort, int iSocketType);
+
 public slots:
 
 	void startJack();
@@ -119,6 +131,8 @@ public slots:
 	void systemTrayContextMenu(const QPoint&);
 	void activatePresetsMenu(QAction *);
 
+	void resetXrunStats();
+
 	void quitMainForm();
 
 protected:
@@ -182,6 +196,7 @@ protected:
 	void showDirtySetupWarning();
 
 	void contextMenuEvent(QContextMenuEvent *);
+	void mousePressEvent(QMouseEvent *pMouseEvent);
 
 private:
 
@@ -231,7 +246,7 @@ private:
 	qjackctlConnectionsForm *m_pConnectionsForm;
 	qjackctlPatchbayForm    *m_pPatchbayForm;
 
-	qjackctlPatchbayRack m_patchbayRack;
+	qjackctlPatchbayRack *m_pPatchbayRack;
 
 	qjackctlSystemTray *m_pSystemTray;
 
