@@ -464,7 +464,7 @@ QPixmap *qjackctlSocketList::createPixmapMerge (
 // Client:port snapshot.
 void qjackctlSocketList::clientPortsSnapshot (void)
 {
-	// Grab JACK client:port's...
+	// Grab JACK client:ports...
 	if (m_pJackClient) {
 		const char **ppszClientPorts = jack_get_ports(m_pJackClient,
 			NULL, JACK_DEFAULT_AUDIO_TYPE,
@@ -484,12 +484,23 @@ void qjackctlSocketList::clientPortsSnapshot (void)
 					if (pSocket)
 						pPlug = pSocket->findPlug(sPortName);
 					if (pSocket == NULL) {
+						int iSocketCount = listView()->topLevelItemCount();
+						if (iSocketCount > 0) {
+							pSocket = static_cast<qjackctlSocketItem *> (
+								listView()->topLevelItem(iSocketCount - 1));
+						}
 						pSocket = new qjackctlSocketItem(this, sClientName,
 							qjackctlClientAlias::escapeRegExpDigits(sClientName),
-							QJACKCTL_SOCKETTYPE_AUDIO, NULL);
+							QJACKCTL_SOCKETTYPE_AUDIO, pSocket);
+					}
+					if (pSocket && pPlug == NULL) {
+						int iPlugCount = pSocket->childCount();
+						if (iPlugCount > 0) {
+							pPlug = static_cast<qjackctlPlugItem *> (
+								pSocket->child(iPlugCount - 1));
+						}
+						pPlug = new qjackctlPlugItem(pSocket, sPortName, pPlug);
 					}
-					if (pSocket && pPlug == NULL)
-						pPlug = new qjackctlPlugItem(pSocket, sPortName, NULL);
 				}
 				iClientPort++;
 			}
@@ -499,9 +510,8 @@ void qjackctlSocketList::clientPortsSnapshot (void)
 
 #ifdef CONFIG_ALSA_SEQ
 
-	// Grab ALSA subscribers's...
+	// Grab ALSA subscribers...
 	if (m_pAlsaSeq) {
-		// Grab the ALSA subscriptions...
 		snd_seq_client_info_t *pClientInfo;
 		snd_seq_port_info_t   *pPortInfo;
 		unsigned int uiAlsaFlags;
@@ -531,12 +541,23 @@ void qjackctlSocketList::clientPortsSnapshot (void)
 						if (pSocket)
 							pPlug = pSocket->findPlug(sPortName);
 						if (pSocket == NULL) {
+							int iSocketCount = listView()->topLevelItemCount();
+							if (iSocketCount > 0) {
+								pSocket = static_cast<qjackctlSocketItem *> (
+									listView()->topLevelItem(iSocketCount - 1));
+							}
 							pSocket = new qjackctlSocketItem(this, sClientName,
 								qjackctlClientAlias::escapeRegExpDigits(sClientName),
-								QJACKCTL_SOCKETTYPE_MIDI, NULL);
+								QJACKCTL_SOCKETTYPE_MIDI, pSocket);
+						}
+						if (pSocket && pPlug == NULL) {
+							int iPlugCount = pSocket->childCount();
+							if (iPlugCount > 0) {
+								pPlug = static_cast<qjackctlPlugItem *> (
+									pSocket->child(iPlugCount - 1));
+							}
+							pPlug = new qjackctlPlugItem(pSocket, sPortName, pPlug);
 						}
-						if (pSocket && pPlug == NULL)
-							pPlug = new qjackctlPlugItem(pSocket, sPortName, NULL);
 					}
 				}
 			}
@@ -586,7 +607,11 @@ bool qjackctlSocketList::addSocketItem (void)
 		qjackctlSocketItem *pSocketItem = selectedSocketItem();
 	//  m_pListView->setUpdatesEnabled(false);
 		if (pSocketItem)
+#if QT_VERSION >= 0x040200
 			pSocketItem->setSelected(false);
+#else
+			m_pListView->setItemSelected(pSocketItem, false);
+#endif
 		pSocketItem = new qjackctlSocketItem(this, socket.name(),
 			socket.clientName(), socket.type(), pSocketItem);
 		if (pSocketItem) {
@@ -600,7 +625,11 @@ bool qjackctlSocketList::addSocketItem (void)
 			}
 			bResult = true;
 		}
+#if QT_VERSION >= 0x040200
 		pSocketItem->setSelected(true);
+#else
+		m_pListView->setItemSelected(pSocketItem, true);
+#endif
 		m_pListView->setCurrentItem(pSocketItem);
 	//  m_pListView->setUpdatesEnabled(true);
 	//  m_pListView->update();
@@ -676,7 +705,11 @@ bool qjackctlSocketList::editSocketItem (void)
 				pPlugItem = new qjackctlPlugItem(
 					pSocketItem, iter.next(), pPlugItem);
 			}
+#if QT_VERSION >= 0x040200
 			pSocketItem->setSelected(true);
+#else
+			m_pListView->setItemSelected(pSocketItem, true);
+#endif
 			m_pListView->setCurrentItem(pSocketItem);
 		//  m_pListView->setUpdatesEnabled(true);
 		//  m_pListView->triggerUpdate();
@@ -735,7 +768,11 @@ bool qjackctlSocketList::copySocketItem (void)
 				}
 				bResult = true;
 			}
+#if QT_VERSION >= 0x040200
 			pSocketItem->setSelected(true);
+#else
+			m_pListView->setItemSelected(pSocketItem, true);
+#endif
 			m_pListView->setCurrentItem(pSocketItem);
 		//  m_pListView->setUpdatesEnabled(true);
 		//  m_pListView->triggerUpdate();
@@ -776,7 +813,11 @@ bool qjackctlSocketList::moveUpSocketItem (void)
 			QTreeWidgetItem *pItem = m_pListView->takeTopLevelItem(iItem);
 			if (pItem) {
 				m_pListView->insertTopLevelItem(iItem - 1, pItem);
+#if QT_VERSION >= 0x040200
 				pSocketItem->setSelected(true);
+#else
+				m_pListView->setItemSelected(pSocketItem, true);
+#endif
 				m_pListView->setCurrentItem(pSocketItem);
 			//  m_pListView->setUpdatesEnabled(true);
 			//  m_pListView->update();
@@ -803,7 +844,11 @@ bool qjackctlSocketList::moveDownSocketItem (void)
 			QTreeWidgetItem *pItem = m_pListView->takeTopLevelItem(iItem);
 			if (pItem) {
 				m_pListView->insertTopLevelItem(iItem + 1, pItem);
+#if QT_VERSION >= 0x040200
 				pSocketItem->setSelected(true);
+#else
+				m_pListView->setItemSelected(pSocketItem, true);
+#endif
 				m_pListView->setCurrentItem(pSocketItem);
 			//  m_pListView->setUpdatesEnabled(true);
 			//  m_pListView->update();
