@@ -166,7 +166,6 @@ void qjackctlPatchbayForm::showEvent ( QShowEvent *pShowEvent )
 	QWidget::showEvent(pShowEvent);
 }
 
-
 // Notify our parent that we're closing.
 void qjackctlPatchbayForm::hideEvent ( QHideEvent *pHideEvent )
 {
@@ -177,6 +176,16 @@ void qjackctlPatchbayForm::hideEvent ( QHideEvent *pHideEvent )
 		pMainForm->stabilizeForm();
 }
 
+// Just about to notify main-window that we're closing.
+void qjackctlPatchbayForm::closeEvent ( QCloseEvent * /*pCloseEvent*/ )
+{
+	QWidget::hide();
+
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm)
+		pMainForm->stabilizeForm();
+}
+
 
 // Set reference to global options, mostly needed for the
 // initial sizes of the main splitter views...
@@ -402,6 +411,20 @@ bool qjackctlPatchbayForm::savePatchbayFile ( const QString& sFileName )
 }
 
 
+// Dirty-(re)load patchbay definitions from know rack.
+void qjackctlPatchbayForm::loadPatchbayRack ( qjackctlPatchbayRack *pRack )
+{
+	// Step 1: load from rack...
+	m_pPatchbay->loadRack(pRack);
+
+	// Override dirty flag.
+	m_ui.PatchbayView->setDirty(true);
+
+	// Done.
+	stabilizeForm();
+}
+
+
 // Create a new patchbay definition from scratch.
 void qjackctlPatchbayForm::newPatchbay (void)
 {
