@@ -354,7 +354,7 @@ qjackctlPatchbaySlot *qjackctlPatchbayRack::findSlot ( const QString& sSlotName
 }
 
 
-// Cable finder.
+// Cable finders.
 qjackctlPatchbayCable *qjackctlPatchbayRack::findCable (
 	const QString& sOutputSocket, const QString& sInputSocket )
 {
@@ -389,6 +389,62 @@ qjackctlPatchbayCable *qjackctlPatchbayRack::findCable (
 }
 
 
+// Cable finder (logical matching by client/port names).
+qjackctlPatchbayCable *qjackctlPatchbayRack::findCable (
+	const QString& sOClientName, const QString& sOPortName,
+	const QString& sIClientName, const QString& sIPortName,
+	int iSocketType )
+{
+	// This is a regex prefix needed for ALSA MDII
+	// as client and port names include id-number+colon...
+	QString sPrefix;
+	if (iSocketType == QJACKCTL_SOCKETTYPE_MIDI)
+		sPrefix = "[0-9]+:";
+	
+	// Scan from output-socket list...
+	QListIterator<qjackctlPatchbaySocket *> osocket(m_osocketlist);
+	while (osocket.hasNext()) {
+		qjackctlPatchbaySocket *pOSocket = osocket.next();
+		if (pOSocket->type() != iSocketType)
+			continue;
+		// Output socket client name match?
+		if (!QRegExp(sPrefix + pOSocket->clientName())
+			.exactMatch(sOClientName))
+			continue;
+		// Output plug port names match?
+		QStringListIterator oplug(pOSocket->pluglist());
+		while (oplug.hasNext()) {
+			if (!QRegExp(sPrefix + oplug.next())
+				.exactMatch(sOPortName))
+				continue;
+			// Scan for output-socket cable...
+			QListIterator<qjackctlPatchbayCable *> cable(m_cablelist);
+			while (cable.hasNext()) {
+				qjackctlPatchbayCable *pCable = cable.next();
+				if (pCable->outputSocket() != pOSocket)
+					continue;
+				qjackctlPatchbaySocket *pISocket = pCable->inputSocket();
+				// Input socket client name match?
+				if (!QRegExp(sPrefix + pISocket->clientName())
+					.exactMatch(sIClientName))
+					continue;
+				// Input plug port names match?
+				QStringListIterator iplug(pISocket->pluglist());
+				while (iplug.hasNext()) {
+					// Found it?
+					if (QRegExp(sPrefix + iplug.next())
+						.exactMatch(sIPortName))
+						return pCable;
+				}
+			}
+		}
+	}
+
+	// No matching cable was found.
+	return NULL;
+}
+
+
 // Patckbay cleaners.
 void qjackctlPatchbayRack::clear (void)
 {
@@ -561,18 +617,20 @@ void qjackctlPatchbayRack::connectAudioCable (
 		const QString& sOutputPlug = iterOutputPlug.next();
 		const QString& sInputPlug  = iterInputPlug.next();
 		// Check audio port connection sequentially...
-		int iPort = 0;
+		int iOPort = 0;
 		const char *pszOutputPort;
 		while ((pszOutputPort = findAudioPort(m_ppszOAudioPorts,
-			pOutputSocket->clientName(), sOutputPlug, iPort)) != NULL) {
-			const char *pszInputPort = findAudioPort(m_ppszIAudioPorts,
-				pInputSocket->clientName(), sInputPlug, iPort);
-			if (pszInputPort) {
+				pOutputSocket->clientName(), sOutputPlug, iOPort)) != NULL) {
+			int iIPort = 0;
+			const char *pszInputPort;
+			while ((pszInputPort = findAudioPort(m_ppszIAudioPorts,
+					pInputSocket->clientName(), sInputPlug, iIPort)) != NULL) {
 				connectAudioSocketPorts(
-					pOutputSocket, pszOutputPort,
-					pInputSocket, pszInputPort);
+					 pOutputSocket, pszOutputPort,
+					 pInputSocket, pszInputPort);
+				iIPort++;
 			}
-			iPort++;
+			iOPort++;
 		}
 	}
 }
@@ -929,18 +987,20 @@ void qjackctlPatchbayRack::connectMidiCable (
 		const QString& sOutputPlug = iterOutputPlug.next();
 		const QString& sInputPlug  = iterInputPlug.next();
 		// Check MIDI port connection sequentially...
-		int iPort = 0;
+		int iOPort = 0;
 		qjackctlMidiPort *pOutputPort;
 		while ((pOutputPort = findMidiPort(m_omidiports,
-				pOutputSocket->clientName(), sOutputPlug, iPort)) != NULL) {
-			qjackctlMidiPort *pInputPort = findMidiPort(m_imidiports,
-				pInputSocket->clientName(), sInputPlug, iPort);
-			if (pInputPort) {
+				pOutputSocket->clientName(), sOutputPlug, iOPort)) != NULL) {
+			int iIPort = 0;
+			qjackctlMidiPort *pInputPort;
+			while ((pInputPort = findMidiPort(m_imidiports,
+					pInputSocket->clientName(), sInputPlug, iIPort)) != NULL) {
 				connectMidiSocketPorts(
-					pOutputSocket, pOutputPort,
-					pInputSocket, pInputPort);
+					 pOutputSocket, pOutputPort,
+					 pInputSocket, pInputPort);
+				iIPort++;
 			}
-			iPort++;
+			iOPort++;
 		}
 	}
 }
