@@ -64,8 +64,10 @@ qjackctlSetup::qjackctlSetup (void)
 	bXrunIgnoreFirst         = m_settings.value("/XrunIgnoreFirst", false).toBool();
 	bActivePatchbay          = m_settings.value("/ActivePatchbay", false).toBool();
 	sActivePatchbayPath      = m_settings.value("/ActivePatchbayPath").toString();
+#ifdef CONFIG_AUTO_REFRESH
 	bAutoRefresh             = m_settings.value("/AutoRefresh", false).toBool();
 	iTimeRefresh             = m_settings.value("/TimeRefresh", 10).toInt();
+#endif
 	bBezierLines             = m_settings.value("/BezierLines", false).toBool();
 	iTimeDisplay             = m_settings.value("/TimeDisplay", 0).toInt();
 	iTimeFormat              = m_settings.value("/TimeFormat", 0).toInt();
@@ -75,16 +77,19 @@ qjackctlSetup::qjackctlSetup (void)
 	sDisplayFont1            = m_settings.value("/DisplayFont1").toString();
 	sDisplayFont2            = m_settings.value("/DisplayFont2").toString();
 	bDisplayEffect           = m_settings.value("/DisplayEffect", true).toBool();
+	bDisplayBlink            = m_settings.value("/DisplayBlink", true).toBool();
 	iConnectionsIconSize     = m_settings.value("/ConnectionsIconSize", QJACKCTL_ICON_16X16).toInt();
 	sConnectionsFont         = m_settings.value("/ConnectionsFont").toString();
 	bQueryClose              = m_settings.value("/QueryClose", true).toBool();
 	bKeepOnTop               = m_settings.value("/KeepOnTop", false).toBool();
 	bSystemTray              = m_settings.value("/SystemTray", false).toBool();
+	bStartMinimized          = m_settings.value("/StartMinimized", false).toBool();
 	bDelayedSetup            = m_settings.value("/DelayedSetup", false).toBool();
 	bServerConfig            = m_settings.value("/ServerConfig", true).toBool();
 	sServerConfigName        = m_settings.value("/ServerConfigName", ".jackdrc").toString();
 	bServerConfigTemp        = m_settings.value("/ServerConfigTemp", false).toBool();
 	bQueryShutdown           = m_settings.value("/QueryShutdown", true).toBool();
+	bAlsaSeqEnabled          = m_settings.value("/AlsaSeqEnabled", true).toBool();
 	bAliasesEnabled          = m_settings.value("/AliasesEnabled", false).toBool();
 	bAliasesEditing          = m_settings.value("/AliasesEditing", false).toBool();
 	bLeftButtons             = m_settings.value("/LeftButtons", true).toBool();
@@ -147,8 +152,10 @@ qjackctlSetup::~qjackctlSetup (void)
 	m_settings.setValue("/XrunIgnoreFirst",         bXrunIgnoreFirst);
 	m_settings.setValue("/ActivePatchbay",          bActivePatchbay);
 	m_settings.setValue("/ActivePatchbayPath",      sActivePatchbayPath);
+#ifdef CONFIG_AUTO_REFRESH
 	m_settings.setValue("/AutoRefresh",             bAutoRefresh);
 	m_settings.setValue("/TimeRefresh",             iTimeRefresh);
+#endif
 	m_settings.setValue("/BezierLines",             bBezierLines);
 	m_settings.setValue("/TimeDisplay",             iTimeDisplay);
 	m_settings.setValue("/TimeFormat",              iTimeFormat);
@@ -158,16 +165,19 @@ qjackctlSetup::~qjackctlSetup (void)
 	m_settings.setValue("/DisplayFont1",            sDisplayFont1);
 	m_settings.setValue("/DisplayFont2",            sDisplayFont2);
 	m_settings.setValue("/DisplayEffect",           bDisplayEffect);
+	m_settings.setValue("/DisplayBlink",            bDisplayBlink);
 	m_settings.setValue("/ConnectionsIconSize",     iConnectionsIconSize);
 	m_settings.setValue("/ConnectionsFont",         sConnectionsFont);
 	m_settings.setValue("/QueryClose",              bQueryClose);
 	m_settings.setValue("/KeepOnTop",               bKeepOnTop);
 	m_settings.setValue("/SystemTray",              bSystemTray);
+	m_settings.setValue("/StartMinimized",          bStartMinimized);
 	m_settings.setValue("/DelayedSetup",            bDelayedSetup);
 	m_settings.setValue("/ServerConfig",            bServerConfig);
 	m_settings.setValue("/ServerConfigName",        sServerConfigName);
 	m_settings.setValue("/ServerConfigTemp",        bServerConfigTemp);
 	m_settings.setValue("/QueryShutdown",           bQueryShutdown);
+	m_settings.setValue("/AlsaSeqEnabled",          bAlsaSeqEnabled);
 	m_settings.setValue("/AliasesEnabled",          bAliasesEnabled);
 	m_settings.setValue("/AliasesEditing",          bAliasesEditing);
 	m_settings.setValue("/LeftButtons",             bLeftButtons);
@@ -568,7 +578,7 @@ void qjackctlSetup::saveSplitterSizes ( QSplitter *pSplitter )
 //---------------------------------------------------------------------------
 // Widget geometry persistence helper methods.
 
-void qjackctlSetup::loadWidgetGeometry ( QWidget *pWidget )
+void qjackctlSetup::loadWidgetGeometry ( QWidget *pWidget, bool bMinimized )
 {
 	// Try to restore old form window positioning.
 	if (pWidget) {
@@ -582,13 +592,13 @@ void qjackctlSetup::loadWidgetGeometry ( QWidget *pWidget )
 		fsize.setHeight(m_settings.value("/height", -1).toInt());
 		bVisible = m_settings.value("/visible", false).toBool();
 		m_settings.endGroup();
-		new qjackctlDelayedSetup(pWidget, fpos, fsize, bVisible,
+		new qjackctlDelayedSetup(pWidget, fpos, fsize, bVisible && !bMinimized,
 			(bDelayedSetup ? 1000 : 0));
 	}
 }
 
 
-void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget )
+void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget, bool bMinimized )
 {
 	// Try to save form window position...
 	// (due to X11 window managers ideossincrasies, we better
@@ -596,15 +606,13 @@ void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget )
 	if (pWidget) {
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
 		bool bVisible = pWidget->isVisible();
-		if (bVisible) {
-			QPoint fpos  = pWidget->pos();
-			QSize  fsize = pWidget->size();
-			m_settings.setValue("/x", fpos.x());
-			m_settings.setValue("/y", fpos.y());
-			m_settings.setValue("/width", fsize.width());
-			m_settings.setValue("/height", fsize.height());
-		}
-		m_settings.setValue("/visible", bVisible);
+		const QPoint& fpos  = pWidget->pos();
+		const QSize&  fsize = pWidget->size();
+		m_settings.setValue("/x", fpos.x());
+		m_settings.setValue("/y", fpos.y());
+		m_settings.setValue("/width", fsize.width());
+		m_settings.setValue("/height", fsize.height());
+		m_settings.setValue("/visible", bVisible && !bMinimized);
 		m_settings.endGroup();
 	}
 }
