@@ -123,8 +123,10 @@ public:
 	bool    bXrunIgnoreFirst;
 	bool    bActivePatchbay;
 	QString sActivePatchbayPath;
+#ifdef CONFIG_AUTO_REFRESH
 	bool    bAutoRefresh;
 	int     iTimeRefresh;
+#endif
 	bool    bBezierLines;
 	int     iTimeDisplay;
 	int     iTimeFormat;
@@ -134,16 +136,19 @@ public:
 	QString sDisplayFont1;
 	QString sDisplayFont2;
 	bool    bDisplayEffect;
+	bool    bDisplayBlink;
 	int     iConnectionsIconSize;
 	QString sConnectionsFont;
 	bool    bQueryClose;
 	bool    bKeepOnTop;
 	bool    bSystemTray;
+	bool    bStartMinimized;
 	bool    bDelayedSetup;
 	bool    bServerConfig;
 	QString sServerConfigName;
 	bool    bServerConfigTemp;
 	bool    bQueryShutdown;
+	bool    bAlsaSeqEnabled;
 	bool    bAliasesEnabled;
 	bool    bAliasesEditing;
 	bool    bLeftButtons;
@@ -181,8 +186,8 @@ public:
 	void saveSplitterSizes(QSplitter *pSplitter);
 
 	// Widget geometry persistence helper prototypes.
-	void saveWidgetGeometry(QWidget *pWidget);
-	void loadWidgetGeometry(QWidget *pWidget);
+	void saveWidgetGeometry(QWidget *pWidget, bool bMinimized = false);
+	void loadWidgetGeometry(QWidget *pWidget, bool bMinimized = false);
 
 private:
 
