@@ -89,8 +89,10 @@ qjackctlSetupForm::qjackctlSetupForm (
 		new QIntValidator(m_ui.WordLengthComboBox));
 	m_ui.TimeoutComboBox->setValidator(
 		new QIntValidator(m_ui.TimeoutComboBox));
+#ifdef CONFIG_AUTO_REFRESH
 	m_ui.TimeRefreshComboBox->setValidator(
 		new QIntValidator(m_ui.TimeRefreshComboBox));
+#endif
 	m_ui.PortMaxComboBox->setValidator(
 		new QIntValidator(m_ui.PortMaxComboBox));
 	m_ui.MessagesLimitLinesComboBox->setValidator(
@@ -287,14 +289,14 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.ActivePatchbayPathToolButton,
 		SIGNAL(clicked()),
 		SLOT(browseActivePatchbayPath()));
-
+#ifdef CONFIG_AUTO_REFRESH
 	QObject::connect(m_ui.AutoRefreshCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
 	QObject::connect(m_ui.TimeRefreshComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(optionsChanged()));
-
+#endif
 	QObject::connect(m_ui.TransportTimeRadioButton,
 		SIGNAL(toggled(bool)),
 		SLOT(optionsChanged()));
@@ -313,6 +315,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.DisplayEffectCheckBox,
 		SIGNAL(toggled(bool)),
 		SLOT(toggleDisplayEffect(bool)));
+	QObject::connect(m_ui.DisplayBlinkCheckBox,
+		SIGNAL(toggled(bool)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.DisplayFont1PushButton,
 		SIGNAL(clicked()),
 		SLOT(chooseDisplayFont1()));
@@ -356,6 +361,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.SystemTrayCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.StartMinimizedCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.DelayedSetupCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
@@ -371,6 +379,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.QueryShutdownCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.AlsaSeqEnabledCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.LeftButtonsCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
@@ -463,9 +474,14 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.ActivePatchbayCheckBox->setChecked(m_pSetup->bActivePatchbay);
 	setComboBoxCurrentText(m_ui.ActivePatchbayPathComboBox,
 		m_pSetup->sActivePatchbayPath);
+#ifdef CONFIG_AUTO_REFRESH
 	m_ui.AutoRefreshCheckBox->setChecked(m_pSetup->bAutoRefresh);
 	setComboBoxCurrentText(m_ui.TimeRefreshComboBox,
 		QString::number(m_pSetup->iTimeRefresh));
+#else
+	m_ui.AutoRefreshCheckBox->setVisible(false);
+	m_ui.TimeRefreshComboBox->setVisible(false);
+#endif
 	m_ui.BezierLinesCheckBox->setChecked(m_pSetup->bBezierLines);
 
 	// Load some other defaults...
@@ -518,6 +534,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 
 	// The main display shiny effect option.
 	m_ui.DisplayEffectCheckBox->setChecked(m_pSetup->bDisplayEffect);
+	m_ui.DisplayBlinkCheckBox->setChecked(m_pSetup->bDisplayBlink);
 	toggleDisplayEffect(m_pSetup->bDisplayEffect);
 
 	// Connections view icon size.
@@ -534,12 +551,14 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.QueryCloseCheckBox->setChecked(m_pSetup->bQueryClose);
 	m_ui.KeepOnTopCheckBox->setChecked(m_pSetup->bKeepOnTop);
 	m_ui.SystemTrayCheckBox->setChecked(m_pSetup->bSystemTray);
+	m_ui.StartMinimizedCheckBox->setChecked(m_pSetup->bStartMinimized);
 	m_ui.DelayedSetupCheckBox->setChecked(m_pSetup->bDelayedSetup);
 	m_ui.ServerConfigCheckBox->setChecked(m_pSetup->bServerConfig);
 	setComboBoxCurrentText(m_ui.ServerConfigNameComboBox,
 		m_pSetup->sServerConfigName);
 	m_ui.ServerConfigTempCheckBox->setChecked(m_pSetup->bServerConfigTemp);
 	m_ui.QueryShutdownCheckBox->setChecked(m_pSetup->bQueryShutdown);
+	m_ui.AlsaSeqEnabledCheckBox->setChecked(m_pSetup->bAlsaSeqEnabled);
 	m_ui.AliasesEnabledCheckBox->setChecked(m_pSetup->bAliasesEnabled);
 	m_ui.AliasesEditingCheckBox->setChecked(m_pSetup->bAliasesEditing);
 	m_ui.LeftButtonsCheckBox->setChecked(!m_pSetup->bLeftButtons);
@@ -550,12 +569,17 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 #ifndef CONFIG_SYSTEM_TRAY
 	m_ui.SystemTrayCheckBox->setChecked(false);
 	m_ui.SystemTrayCheckBox->setEnabled(false);
+	m_ui.StartMinimizedCheckBox->setChecked(false);
+	m_ui.StartMinimizedCheckBox->setEnabled(false);
 #endif
 #ifndef CONFIG_JACK_MIDI
 	m_ui.MidiDriverComboBox->setCurrentIndex(0);
 	m_ui.MidiDriverTextLabel->setEnabled(false);
 	m_ui.MidiDriverComboBox->setEnabled(false);
 #endif
+#ifndef CONFIG_ALSA_SEQ
+	m_ui.AlsaSeqEnabledCheckBox->setEnabled(false);
+#endif
 
 	// Load preset list...
 	resetPresets();
@@ -815,6 +839,7 @@ void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 	bool bOss        = (sDriver == "oss");
 	bool bAlsa       = (sDriver == "alsa");
 	bool bCoreaudio  = (sDriver == "coreaudio");
+	bool bPortaudio  = (sDriver == "portaudio");
 	bool bFreebob    = (sDriver == "freebob");
 	bool bFirewire   = (sDriver == "firewire");
 	bool bInEnabled  = false;
@@ -822,14 +847,14 @@ void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 
 	switch (iAudio) {
 	case QJACKCTL_DUPLEX:
-		bInEnabled  = (bOss || bAlsa || bCoreaudio);
-		bOutEnabled = (bOss || bAlsa || bCoreaudio);
+		bInEnabled  = (bOss || bAlsa || bCoreaudio || bPortaudio);
+		bOutEnabled = (bOss || bAlsa || bCoreaudio || bPortaudio);
 		break;
 	case QJACKCTL_CAPTURE:
-		bInEnabled  = (bOss || bCoreaudio);
+		bInEnabled  = (bOss || bCoreaudio || bPortaudio);
 		break;
 	case QJACKCTL_PLAYBACK:
-		bOutEnabled = (bOss || bCoreaudio);
+		bOutEnabled = (bOss || bCoreaudio || bPortaudio);
 		break;
 	}
 
@@ -986,12 +1011,16 @@ void qjackctlSetupForm::stabilizeForm (void)
 	bEnabled = m_ui.ActivePatchbayCheckBox->isChecked();
 	m_ui.ActivePatchbayPathComboBox->setEnabled(bEnabled);
 	m_ui.ActivePatchbayPathToolButton->setEnabled(bEnabled);
-
+#ifdef CONFIG_AUTO_REFRESH
 	m_ui.TimeRefreshComboBox->setEnabled(
 		m_ui.AutoRefreshCheckBox->isChecked());
+#endif
 	m_ui.MessagesLimitLinesComboBox->setEnabled(
 		m_ui.MessagesLimitCheckBox->isChecked());
 
+	m_ui.StartMinimizedCheckBox->setEnabled(
+		m_ui.SystemTrayCheckBox->isChecked());
+
 	bEnabled = m_ui.ServerConfigCheckBox->isChecked();
 	m_ui.ServerConfigNameComboBox->setEnabled(bEnabled);
 	m_ui.ServerConfigTempCheckBox->setEnabled(bEnabled);
@@ -1559,8 +1588,10 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->bXrunIgnoreFirst         = m_ui.XrunIgnoreFirstCheckBox->isChecked();
 		m_pSetup->bActivePatchbay          = m_ui.ActivePatchbayCheckBox->isChecked();
 		m_pSetup->sActivePatchbayPath      = m_ui.ActivePatchbayPathComboBox->currentText();
+#ifdef CONFIG_AUTO_REFRESH
 		m_pSetup->bAutoRefresh             = m_ui.AutoRefreshCheckBox->isChecked();
 		m_pSetup->iTimeRefresh             = m_ui.TimeRefreshComboBox->currentText().toInt();
+#endif
 		m_pSetup->bBezierLines             = m_ui.BezierLinesCheckBox->isChecked();
 		// Save Defaults...
 		m_pSetup->iTimeDisplay             = m_pTimeDisplayButtonGroup->checkedId();
@@ -1571,17 +1602,20 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->sDisplayFont1            = m_ui.DisplayFont1TextLabel->font().toString();
 		m_pSetup->sDisplayFont2            = m_ui.DisplayFont2TextLabel->font().toString();
 		m_pSetup->bDisplayEffect           = m_ui.DisplayEffectCheckBox->isChecked();
+		m_pSetup->bDisplayBlink            = m_ui.DisplayBlinkCheckBox->isChecked();
 		m_pSetup->iConnectionsIconSize     = m_ui.ConnectionsIconSizeComboBox->currentIndex();
 		m_pSetup->sConnectionsFont         = m_ui.ConnectionsFontTextLabel->font().toString();
 		m_pSetup->bStartJack               = m_ui.StartJackCheckBox->isChecked();
 		m_pSetup->bQueryClose              = m_ui.QueryCloseCheckBox->isChecked();
 		m_pSetup->bKeepOnTop               = m_ui.KeepOnTopCheckBox->isChecked();
 		m_pSetup->bSystemTray              = m_ui.SystemTrayCheckBox->isChecked();
+		m_pSetup->bStartMinimized          = m_ui.StartMinimizedCheckBox->isChecked();
 		m_pSetup->bDelayedSetup            = m_ui.DelayedSetupCheckBox->isChecked();
 		m_pSetup->bServerConfig            = m_ui.ServerConfigCheckBox->isChecked();
 		m_pSetup->sServerConfigName        = m_ui.ServerConfigNameComboBox->currentText();
 		m_pSetup->bServerConfigTemp        = m_ui.ServerConfigTempCheckBox->isChecked();
 		m_pSetup->bQueryShutdown           = m_ui.QueryShutdownCheckBox->isChecked();
+		m_pSetup->bAlsaSeqEnabled          = m_ui.AlsaSeqEnabledCheckBox->isChecked();
 		m_pSetup->bAliasesEnabled          = m_ui.AliasesEnabledCheckBox->isChecked();
 		m_pSetup->bAliasesEditing          = m_ui.AliasesEditingCheckBox->isChecked();
 		m_pSetup->bLeftButtons             = !m_ui.LeftButtonsCheckBox->isChecked();
